@@ -84,6 +84,9 @@ gb_gnome_db_logindlg_new (GbWidgetNewData *data)
   gtk_signal_connect (GTK_OBJECT (widget), "delete_event",
 		      GTK_SIGNAL_FUNC (editor_close_window), NULL);
 
+  gtk_object_set_data (GTK_OBJECT (widget), TypeHint,
+		       GINT_TO_POINTER (GLADE_TYPE_HINT_DIALOG_INDEX));
+
   return widget;
 }
 
